==> conf_ini_g-2024.13.tar.gz: conf_ini_g-2024.13/package/conf_ini_g/interface/window/config/advanced.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2021
SEE COPYRIGHT NOTICE BELOW
"""

import typing as h

from babelwidget.main import backend_t, hbox_lyt_h
from conf_ini_g.catalog.boolean import boolean_wgt_t
from str_to_obj.api.catalog import boolean_mode_e, boolean_t
from str_to_obj.api.type import type_t


def AdvancedModeLayout(
    advanced_mode: bool, backend: backend_t, ToggleAdvancedMode: h.Callable, /
) -> tuple[hbox_lyt_h, boolean_wgt_t]:
    """"""
    layout = backend.hbox_lyt_t()

    annotated_type = h.Annotated[bool, boolean_t(mode=boolean_mode_e.on_off)]
    stripe = type_t.NewForHint(annotated_type)
    boolean = boolean_wgt_t.NewForSpecification(stripe, backend)
    boolean.Assign(advanced_mode, None)
    boolean.true_btn.SetFunction(ToggleAdvancedMode)

    layout.addWidget(backend.label_t("<i>Advanced Mode</i>"))
    layout.addWidget(boolean.library_wgt)

    return layout, boolean


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""

==> conf_ini_g-2025.6.tar.gz: conf_ini_g-2025.6/package/conf_ini_g/interface/window/config/advanced.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2021
SEE COPYRIGHT NOTICE BELOW
"""

import typing as h

from babelwidget.api.backend import backend_t
from babelwidget.api.widget import hbox_lyt_h
from conf_ini_g.catalog.boolean import boolean_wgt_t
from value_factory.api.catalog import boolean_mode_e, boolean_t
from value_factory.api.type import hint_t


def AdvancedModeLayout(
    advanced_mode: bool, backend: backend_t, ToggleAdvancedMode: h.Callable, /
) -> tuple[hbox_lyt_h, boolean_wgt_t]:
    """"""
    layout = backend.hbox_lyt_t()

    annotated_type = h.Annotated[bool, boolean_t(boolean_mode_e.on_off)]
    stripe = hint_t.New(annotated_type)
    boolean = boolean_wgt_t.New(stripe, backend)
    boolean.Assign(advanced_mode, None)
    boolean.true_btn.SetFunction(ToggleAdvancedMode)

    layout.addWidget(backend.label_t("<i>Advanced Mode</i>"))
    layout.addWidget(boolean.library_wgt)

    return layout, boolean


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""
